bayespy.inference.vmp.nodes.binomial.BinomialDistribution.compute_message_to_parent
===================================================================================

.. currentmodule:: bayespy.inference.vmp.nodes.binomial

.. automethod:: BinomialDistribution.compute_message_to_parent